Permissions | User | Group     | Size      | Last Modified             | File Type | Filename                                                                                                                     
----------- | ---- | --------- | --------- | ------------------------- | --------- | -----------------------------------------------------------------------------------------------------------------------------
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/                                                                                               
0755        | mdf  | all_users | 4096      | 2018-09-11 14:43:15+00:00 | dir       | published/                                                                                                                   
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/                                                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/                                                                              
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:24+00:00 | dir       | musinski_afrl_am_package_v2.1/Input Data/                                                                                    
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Supplemental Data/                                                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Validation Data/                                                                               
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/                                                                                            
0644        | mdf  | all_users | 362611    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Challenge 1 Answer Template.xlsx                                                               
0644        | mdf  | all_users | 3074404   | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Challenge 1 Problem Statement_2019Release.pdf                                                  
0644        | mdf  | all_users | 223521    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Challenge Series Webpage including FAQ.pdf                                                     
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/                                                         
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/                                                
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/                                                                
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/                                      
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/                                                                  
0644        | mdf  | all_users | 25128     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/4-10-17 AFRL PtS Build_2017_04_10_splice.oxy                                  
0644        | mdf  | all_users | 104482    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/HomeIn-Build A.csv                                                            
0644        | mdf  | all_users | 34648     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Size.xlsx                                                              
0644        | mdf  | all_users | 188294    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/layer_absolute_times.png                                                      
0644        | mdf  | all_users | 61169     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/layer_elapsed_times.png                                                       
0644        | mdf  | all_users | 80449     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/oxygen.png                                                                    
0644        | mdf  | all_users | 4534      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A46 - 10mm x 1mm.STEP                                    
0644        | mdf  | all_users | 884       | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A46 - 10mm x 1mm.STL                                     
0644        | mdf  | all_users | 4538      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A48 - 10mm x 5mm.STEP                                    
0644        | mdf  | all_users | 884       | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A48 - 10mm x 5mm.STL                                     
0644        | mdf  | all_users | 4529      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A51 - 30mm x 5mm.STEP                                    
0644        | mdf  | all_users | 884       | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A51 - 30mm x 5mm.STL                                     
0644        | mdf  | all_users | 4529      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A52 - 50mm x 1mm.STEP                                    
0644        | mdf  | all_users | 884       | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A52 - 50mm x 1mm.STL                                     
0644        | mdf  | all_users | 4539      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A54 - 50mm x 5mm.STEP                                    
0644        | mdf  | all_users | 884       | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/A54 - 50mm x 5mm.STL                                     
0644        | mdf  | all_users | 2855184   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Build Layout Details/Build A - All Parts Combined.STL                         
0644        | mdf  | all_users | 86999268  | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/A46_MIDAS_opticalcrosssection with scale bar.tif
0644        | mdf  | all_users | 86999445  | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/A46_MIDAS_opticalcrosssection.tif               
0644        | mdf  | all_users | 148828212 | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/A48_MIDAS_opticalcrosssection with scale bar.tif
0644        | mdf  | all_users | 148828217 | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/A48_MIDAS_opticalcrosssection.tif               
0644        | mdf  | all_users | 2000341   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/OpticalCrossSections_A46and48/cal_standard.tif                                
0644        | mdf  | all_users | 1062      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_0-tif.hdr                                            
0644        | mdf  | all_users | 1059004   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_0.tif                                                
0644        | mdf  | all_users | 1064      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_1-tif.hdr                                            
0644        | mdf  | all_users | 1181208   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_1.tif                                                
0644        | mdf  | all_users | 1064      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_2-tif.hdr                                            
0644        | mdf  | all_users | 1181092   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_2.tif                                                
0644        | mdf  | all_users | 1064      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_3-tif.hdr                                            
0644        | mdf  | all_users | 1181122   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_3.tif                                                
0644        | mdf  | all_users | 1064      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_4-tif.hdr                                            
0644        | mdf  | all_users | 1181228   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_4.tif                                                
0644        | mdf  | all_users | 1064      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_5-tif.hdr                                            
0644        | mdf  | all_users | 1181102   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Powder Images/Powder_BSE_5.tif                                                
0644        | mdf  | all_users | 42712     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part - Coordinates.PNG      
0644        | mdf  | all_users | 24277     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 0.PNG            
0644        | mdf  | all_users | 41487     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 125.PNG          
0644        | mdf  | all_users | 48494     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 250.PNG          
0644        | mdf  | all_users | 47246     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 375.PNG          
0644        | mdf  | all_users | 47323     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 500.PNG          
0644        | mdf  | all_users | 39126     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/Build A - Part Layer 625.PNG          
0644        | mdf  | all_users | 106922    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A46_xx.csv                                                        
0644        | mdf  | all_users | 108000    | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A46_zz.csv                                                        
0644        | mdf  | all_users | 164646    | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A48_xx.csv                                                        
0644        | mdf  | all_users | 168660    | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A48_zz.csv                                                        
0644        | mdf  | all_users | 158883    | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A51_xx.csv                                                        
0644        | mdf  | all_users | 161424    | 2021-06-21 18:26:26+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A51_zz.csv                                                        
0644        | mdf  | all_users | 103950    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A52_xx.csv                                                        
0644        | mdf  | all_users | 104521    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A52_zz.csv                                                        
0644        | mdf  | all_users | 204353    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A54_xx.csv                                                        
0644        | mdf  | all_users | 208871    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Calibration Data/Strain Data/A54_zz.csv                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 18:26:27+00:00 | dir       | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/                                                               
0644        | mdf  | all_users | 28652     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A64 - Angled wall 1mm x 5mm.STEP                               
0644        | mdf  | all_users | 1084      | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A64 - Angled wall 1mm x 5mm.STL                                
0644        | mdf  | all_users | 56757     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A67 - 1mm Tube.STEP                                            
0644        | mdf  | all_users | 60284     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A67 - 1mm Tube.STL                                             
0644        | mdf  | all_users | 56757     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A68 - 3mm Tube.STEP                                            
0644        | mdf  | all_users | 59084     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A68 - 3mm Tube.STL                                             
0644        | mdf  | all_users | 56806     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A69 - 5mm Tube.STEP                                            
0644        | mdf  | all_users | 57484     | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Input Data/Build Layout Details/A69 - 5mm Tube.STL                                             
0644        | mdf  | all_users | 1020393   | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Supplemental Data/Supplemental AM IN625 Data.pdf                                               
0644        | mdf  | all_users | 488241    | 2021-06-21 18:26:27+00:00 | file      | musinski_afrl_am_package_v2.1/Validation Data/Challenge1_AnswerKey.xlsx                                                      
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/                                                                           
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:35+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Input Data/                                                                                 
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Supplemental Data/                                                                          
0644        | mdf  | all_users | 362611    | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Challenge 1 Answer Template.xlsx                                                            
0644        | mdf  | all_users | 3074404   | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Challenge 1 Problem Statement_2019Release.pdf                                               
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:38+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/Build Layout Details/                                                      
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/OpticalCrossSections_A46and48/                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/Powder Images/                                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/ScanVectorScreenshots_A51-5mmby30mmWall/                                   
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Calibration Data/Strain Data/                                                               
0644        | mdf  | all_users | 25128     | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/4-10-17 AFRL PtS Build_2017_04_10_splice.oxy                               
0644        | mdf  | all_users | 104482    | 2021-06-21 01:12:36+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/HomeIn-Build A.csv                                                         
0644        | mdf  | all_users | 34648     | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/Powder Size.xlsx                                                           
0644        | mdf  | all_users | 188294    | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/layer_absolute_times.png                                                   
0644        | mdf  | all_users | 61169     | 2021-06-21 01:12:36+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/layer_elapsed_times.png                                                    
0644        | mdf  | all_users | 80449     | 2021-06-21 01:12:36+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Calibration Data/oxygen.png                                                                 
0755        | mdf  | all_users | 4096      | 2021-06-21 01:12:37+00:00 | dir       | musinski_afrl_am_package_v2.1/v1/Input Data/Build Layout Details/                                                            
0644        | mdf  | all_users | 1020393   | 2021-06-21 01:12:37+00:00 | file      | musinski_afrl_am_package_v2.1/v1/Supplemental Data/Supplemental AM IN625 Data.pdf                                            
0755        | mdf  | all_users | 4096      | 2019-09-30 14:04:02+00:00 | dir       | published/publication_1151/                                                                                                  
0755        | mdf  | all_users | 4096      | 2018-06-25 17:45:51+00:00 | dir       | published/publication_1154/                                                                                                  
0755        | mdf  | all_users | 4096      | 2018-09-11 14:43:15+00:00 | dir       | published/publication_1190/                                                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:30+00:00 | dir       | published/publication_1151/data/                                                                                             
0644        | mdf  | all_users | 1983      | 2018-06-22 14:48:40+00:00 | file      | published/publication_1151/globus_metadata.json                                                                              
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:30+00:00 | dir       | published/publication_1151/data/Calibration Data/                                                                            
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:30+00:00 | dir       | published/publication_1151/data/Input Data/                                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:30+00:00 | dir       | published/publication_1151/data/Supplemental Data/                                                                           
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:30+00:00 | dir       | published/publication_1151/data/Validation Data/                                                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 01:13:53+00:00 | dir       | published/publication_1151/data/v1/                                                                                          
0644        | mdf  | all_users | 203832    | 2021-06-21 18:25:30+00:00 | file      | published/publication_1151/data/AFRL Modeling Challenge 2 Data Description - Supplement.pdf                                  
0644        | mdf  | all_users | 15663     | 2021-06-21 18:25:30+00:00 | file      | published/publication_1151/data/Challenge 2 Answer Template.xlsx                                                             
0644        | mdf  | all_users | 2839919   | 2021-06-21 18:25:20+00:00 | file      | published/publication_1151/data/Challenge 2 Problem Statement_2021release.pdf                                                
0644        | mdf  | all_users | 223521    | 2021-06-21 18:25:30+00:00 | file      | published/publication_1151/data/Challenge Series Webpage including FAQ.pdf                                                   
0755        | mdf  | all_users | 4096      | 2019-09-30 14:05:16+00:00 | dir       | published/publication_1154/data/                                                                                             
0644        | mdf  | all_users | 1802      | 2018-06-25 17:45:54+00:00 | file      | published/publication_1154/globus_metadata.json                                                                              
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:05+00:00 | dir       | published/publication_1190/data/                                                                                             
0644        | mdf  | all_users | 1772      | 2018-09-11 14:43:18+00:00 | file      | published/publication_1190/globus_metadata.json                                                                              
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:05+00:00 | dir       | published/publication_1190/data/Calibration Data/                                                                            
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:05+00:00 | dir       | published/publication_1190/data/Input Data/                                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:05+00:00 | dir       | published/publication_1190/data/Pipelines/                                                                                   
0755        | mdf  | all_users | 4096      | 2021-06-21 18:30:55+00:00 | dir       | published/publication_1190/data/Processed Input Data/                                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:04+00:00 | dir       | published/publication_1190/data/Supplemental Data/                                                                           
0755        | mdf  | all_users | 4096      | 2021-06-21 18:32:05+00:00 | dir       | published/publication_1190/data/Validation Data/                                                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 01:16:08+00:00 | dir       | published/publication_1190/data/v1/                                                                                          
0644        | mdf  | all_users | 13414     | 2021-06-21 18:32:05+00:00 | file      | published/publication_1190/data/Challenge 3 Answer Template.xlsx                                                             
0644        | mdf  | all_users | 6256465   | 2021-06-21 18:31:57+00:00 | file      | published/publication_1190/data/Challenge 3 Problem Statement_2021release.pdf                                                
0644        | mdf  | all_users | 223521    | 2021-06-21 18:32:05+00:00 | file      | published/publication_1190/data/Challenge Series Webpage including FAQ.pdf                                                   
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/                                                                                 
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/Input Data/                                                                                       
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/                                                                                
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:43+00:00 | dir       | shade_afrl_am_package_v2.1/Validation Data/                                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:35+00:00 | dir       | shade_afrl_am_package_v2.1/v1/                                                                                               
0644        | mdf  | all_users | 18945     | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Challenge 4  Answer Template.xlsx                                                                 
0644        | mdf  | all_users | 4061762   | 2021-06-21 18:25:41+00:00 | file      | shade_afrl_am_package_v2.1/Challenge 4 Problem Statement_2021release.pdf                                                     
0644        | mdf  | all_users | 223521    | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Challenge Series Webpage including FAQ.pdf                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Build Geometry/                                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:43+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Mechanical Test Data/                                                            
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Microstructure Data/                                                             
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/                                                                       
0644        | mdf  | all_users | 6786484   | 2021-06-21 18:25:41+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Build Geometry/Build C.STL                                                       
0644        | mdf  | all_users | 14720     | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Build Geometry/MIDAS Prism - HEDM Blank.STEP                                     
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Mechanical Test Data/SR+HIP+HT/                                                  
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:43+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Mechanical Test Data/Sample Geometry Details/                                    
0644        | mdf  | all_users | 385377    | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Mechanical Test Data/MIDAS_All_E08_Stress_Strain.png                             
0644        | mdf  | all_users | 307686    | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Mechanical Test Data/MIDAS_All_E08_Stress_Strain_nearYS.png                      
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Microstructure Data/BSE/                                                         
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Microstructure Data/EBSD/                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Calibration Data/Microstructure Data/OM/                                                          
0644        | mdf  | all_users | 10348     | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Microstructure Data/CalibrationMicrostructureData_updated2021.xlsx               
0644        | mdf  | all_users | 41125     | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/CreateTextureInformation.json                                          
0644        | mdf  | all_users | 8894      | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/FindSurfaceRoughness.json                                              
0644        | mdf  | all_users | 939       | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/ImportToH5EBSD.json                                                    
0644        | mdf  | all_users | 18871     | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/Particles.json                                                         
0644        | mdf  | all_users | 9781      | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/Pores.json                                                             
0644        | mdf  | all_users | 89272     | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/ProcessHeatTreatedSpecimens.json                                       
0644        | mdf  | all_users | 51991     | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Calibration Data/Pipelines/ProcessNoHeatTreatedSpecimens.json                                     
0644        | mdf  | all_users | 619726    | 2021-06-21 18:25:42+00:00 | file      | shade_afrl_am_package_v2.1/Input Data/DREAM.3D_Data_Details_v4.pptx                                                          
0644        | mdf  | all_users | 135106345 | 2021-06-21 18:25:39+00:00 | file      | shade_afrl_am_package_v2.1/Input Data/IN625InitialConditions.dream3d                                                         
0644        | mdf  | all_users | 1019      | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Input Data/IN625InitialConditions.xdmf                                                            
0644        | mdf  | all_users | 28162     | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Input Data/MIDAS_HEDM_MechanicalTesting_updated2021.xlsx                                          
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:43+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Mechanical Test Data/                                                           
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:44+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Microstructure Data/                                                            
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Mechanical Test Data/SR Only/                                                   
0644        | mdf  | all_users | 385377    | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Supplemental Data/Mechanical Test Data/MIDAS_All_E08_Stress_Strain.png                            
0644        | mdf  | all_users | 307686    | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Supplemental Data/Mechanical Test Data/MIDAS_All_E08_Stress_Strain_nearYS.png                     
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Microstructure Data/BSE/                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Microstructure Data/EBSD/                                                       
0755        | mdf  | all_users | 4096      | 2021-06-21 18:25:31+00:00 | dir       | shade_afrl_am_package_v2.1/Supplemental Data/Microstructure Data/OM/                                                         
0644        | mdf  | all_users | 11523     | 2021-06-21 18:25:44+00:00 | file      | shade_afrl_am_package_v2.1/Supplemental Data/Microstructure Data/CalibrationMicrostructureData_updated2021.xlsx              
0644        | mdf  | all_users | 19550     | 2021-06-21 18:25:43+00:00 | file      | shade_afrl_am_package_v2.1/Validation Data/Challenge4_AnswerKey.xlsx                                                         
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:16+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Calibration Data/                                                                              
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:36+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Input Data/                                                                                    
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:15+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Supplemental Data/                                                                             
0644        | mdf  | all_users | 18945     | 2021-06-21 01:15:35+00:00 | file      | shade_afrl_am_package_v2.1/v1/Challenge4AnswerTemplate.xlsx                                                                  
0644        | mdf  | all_users | 3013107   | 2021-06-21 01:15:29+00:00 | file      | shade_afrl_am_package_v2.1/v1/Challenge4ProblemStatement_2019Release.pdf                                                     
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:35+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Calibration Data/Build Geometry/                                                               
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:33+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Calibration Data/Mechanical Test Data/                                                         
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:35+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Calibration Data/Microstructure Data/                                                          
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:36+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Calibration Data/Pipelines/                                                                    
0644        | mdf  | all_users | 619726    | 2021-06-21 01:15:33+00:00 | file      | shade_afrl_am_package_v2.1/v1/Input Data/DREAM.3D_Data_Details_v4.pptx                                                       
0644        | mdf  | all_users | 135106345 | 2021-06-21 01:15:23+00:00 | file      | shade_afrl_am_package_v2.1/v1/Input Data/IN625InitialConditions.dream3d                                                      
0644        | mdf  | all_users | 1019      | 2021-06-21 01:15:36+00:00 | file      | shade_afrl_am_package_v2.1/v1/Input Data/IN625InitialConditions.xdmf                                                         
0644        | mdf  | all_users | 27274     | 2021-06-21 01:15:34+00:00 | file      | shade_afrl_am_package_v2.1/v1/Input Data/MIDAS_HEDM_MechanicalTesting.xlsx                                                   
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:40+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Supplemental Data/Mechanical Test Data/                                                        
0755        | mdf  | all_users | 4096      | 2021-06-21 01:15:35+00:00 | dir       | shade_afrl_am_package_v2.1/v1/Supplemental Data/Microstructure Data/                                                         
